%% Figure 1b -- 10 Hour Timepoint %%
% Steven Zwick, 2017 %

% Unit Conversion for all images -- pixel:micron = 1:1.3 
%% NOTE -- DO NOT COPY BTWN time117 AND OTHER TIMEPOINTS WITHOUT FIXING X AND Y SHIFTS

clear; close all; clc;
addpath('../../altmany-export_fig-5be2ca4');
addpath('../../Fiji_scripts/');

%% Load Manually Tracked Results
Ioct4 = double(imread('TLs3_t65_c1.tif'));
Isox2 = double(imread('TLs3_t65_c2.tif'));
nodes = trackmateSpots('../TLs3_manualsegmentation.xml');
x = nodes.POSITION_X(nodes.FRAME==64);
y = nodes.POSITION_Y(nodes.FRAME==64);
oct4 = nodes.MEAN_INTENSITY01(nodes.FRAME==64);
sox2 = nodes.MEAN_INTENSITY02(nodes.FRAME==64);

%% Image Cropping should be done in 1C file

%% Calculate distance from edge
rpoints = 30;
points = rand(100000,2)*1023+1;
emptypoints = zeros(length(points),1);
for p = 1:length(emptypoints)
    emptypoints(p) = all((points(p,1)-x).^2 + (points(p,2)-y).^2 > rpoints.^2);
end
ep = find(emptypoints);

distfromedge = zeros(length(x),1);
for j = 1:length(distfromedge)
    d = (x(j) - points(ep,1)).^2 +...
        (y(j) - points(ep,2)).^2;
    distfromedge(j) = sqrt(min(d))-rpoints;
end
distfromedge(distfromedge<0)=0;
maxdist =max(distfromedge);
Ecells = distfromedge<20; %exterior cells
Icells = distfromedge>=60;%interior cells

%% Show Distance from Edge Results
figure(2);
imshow(imadjust(imread('TLs3_t65_c2.tif'))); 
hold on;
scatter(points(ep,1),points(ep,2),'r','filled');
scatter(x,y,'b');
legend('Empty Points','Cells');
set(gcf, 'Position', get(0, 'Screensize'));
set(gca,'FontSize',26);
export_fig TLs3_t65_emptycells.pdf;
close;

% Add other distance from edge plots here

% figure(65);
% imshow(imadjust(imread('TLs3_t5_c2.tif')),[]); 
% hold on;
% scatter(x(distfromedge<Dcutoff-20),y(distfromedge<Dcutoff-20),'mo');
% scatter(x(distfromedge>Dcutoff+20),y(distfromedge>Dcutoff+20),'bo');
% set(gcf, 'Position', get(0, 'Screensize'));
% set(gca,'FontSize',26);
% export_fig TLs3_t5_cutoffs.pdf;
% close;


%% Calibrate Local Gradient Levels
% fix this so that dark spots in fluorescein dont dim conc
dX = 22;
dY = 21;
Iconc = double(imread('../s3_grad.tif'));
Iconc = (Iconc-min(Iconc(:)))./range(Iconc(:));
Iconcfilt = imgaussfilt(Iconc,30);% HOW TO DETERMINE FILTER LENGTH??
Iconcfilt = (Iconcfilt-min(Iconcfilt(:)))./range(Iconcfilt(:));

Y = max(min(y+dY,1024),1);
X = max(min(x+dX,1024),1);
conc = Iconcfilt(sub2ind(size(Iconcfilt),round(Y),round(X)));

%% Show Gradient Calibration Results

%% Subtracting Background Fluorescence (assuming uniform background)
%this currently has 2 null peaks - will be fixed by cropping image inside channel
[~,Io4density, Io4mesh,~] = kde(Ioct4(:),5000);
[~,Io4maxloc] = max(Io4density);
oct4background = Io4mesh(Io4maxloc);

[~,Is2density, Is2mesh,~] = kde(Isox2(:),5000);
[~,Is2maxloc] = max(Is2density);
sox2background = Is2mesh(Is2maxloc);

% We normalize data at all timepoints to mean fluorescence in first timepoint
oct4mean = mean(nodes.MEAN_INTENSITY01(nodes.FRAME==4));
oct4background0 = 1957.1;
oct4N = (oct4-oct4background)./(oct4mean-oct4background0);
oct4N(oct4N<0) = 0;
sox2mean = mean(nodes.MEAN_INTENSITY02(nodes.FRAME==4));
sox2background0 = 583.8269;
sox2N = (sox2-sox2background)./(sox2mean-sox2background0);
sox2N(sox2N<0) = 0;

%% Showing Background Fluorescence Results 
%% Bin Cells by Concentration
%[~,edges,bin] = histcounts(conc,0:0.09:1);
[~,edges,bin] = histcounts(conc,prctile(conc,0:100/6:100));
edgecenters = (edges(2:end)+edges(1:end-1))./2;

% Only Analyze Bins with >=5 Interior cells
binI = bin(Icells);
[bincountsI,~,~] = histcounts(binI);
binsA = unique(binI);
binsA = binsA(bincountsI>=5); %only keep bins with 5 or more interior cells
nbins = length(binsA);

% Only Keep Cells in Analysis Bins
Ccells = ismember(bin,binsA);
concC = conc(Ccells);
xC = x(Ccells);
yC = y(Ccells);
oct4C = oct4N(Ccells);
sox2C = sox2N(Ccells);
ECcells = Ecells(Ccells);
ICcells = Icells(Ccells);
binC = bin(Ccells);

% Only Keep Exterior/Interior Cells in Analysis Bins
Acells = ECcells | ICcells;
concA = concC(Acells);
xA = xC(Acells);
yA = yC(Acells);
oct4A = oct4C(Acells);
sox2A = sox2C(Acells);
EAcells = ECcells(Acells);
IAcells = ICcells(Acells);
binA = binC(Acells);

%% Show Cells Picked for Analysis
%% Find Mean Sox2 Levels of Exterior and Interior Cells at each Concentration Bin

% set same x / y limits for each timepoint

sox2E = zeros(1,nbins);
sox2I = zeros(1,nbins);
sox2Eci = zeros(2,nbins);
sox2Ici = zeros(2,nbins);
for i = 1:nbins    
    sox2E(i) = mean(sox2A(binA==binsA(i) & EAcells));
    sox2I(i) = mean(sox2A(binA==binsA(i) & IAcells));
    [~,~,sox2Eci(:,i),~] = ttest(sox2A(binA==binsA(i) & EAcells));
    [~,~,sox2Ici(:,i),~] = ttest(sox2A(binA==binsA(i) & IAcells));
end

F4 = figure(4);
set(gcf, 'Position', get(0, 'Screensize'));
set(F4, 'Color', 'w');
PIs2 = errorbar(edgecenters(binsA),sox2I,sox2I-sox2Ici(1,:),sox2Ici(2,:)-sox2I,'b-o','LineWidth',2);   
hold on;
PEs2 = errorbar(edgecenters(binsA)+0.05.*diff(edgecenters(1:2)),sox2E,sox2I-sox2Ici(1,:),sox2Ici(2,:)-sox2I,'m-o','LineWidth',2);
xlim([0.1 0.6]);
ylim([0 1.5]);
a=cellstr(num2str(get(gca,'xtick')'*100)); 
pct = char(ones(size(a,1),1)*'%'); 
new_xticks = [char(a),pct];
set(gca,'xticklabel',new_xticks)
ax = gca;
ax.XAxis.MinorTick = 'on';
ax.YAxis.MinorTick = 'on';
xlabel('Gradient Level');
ylabel('Mean Sox2 Level');
legend([PEs2,PIs2],'Edge of Colony','Interior of Colony', 'Location', 'northeast');
set(gca,'FontSize',26);
export_fig TLs3_t65_gradSox2hist.pdf;
close;

%% Find Mean Oct4 Levels of Exterior and Interior Cells at each Concentration Bin
oct4E = zeros(1,nbins);
oct4I = zeros(1,nbins);
oct4Eci = zeros(2,nbins);
oct4Ici = zeros(2,nbins);
for i = 1:nbins    
    oct4E(i) = mean(oct4A(binA==binsA(i) & EAcells));
    oct4I(i) = mean(oct4A(binA==binsA(i) & IAcells));
    [~,~,oct4Eci(:,i),~] = ttest(oct4A(binA==binsA(i) & EAcells));
    [~,~,oct4Ici(:,i),~] = ttest(oct4A(binA==binsA(i) & IAcells));
end

F4 = figure(4);
set(gcf, 'Position', get(0, 'Screensize'));
set(F4, 'Color', 'w');
PIo4 = errorbar(edgecenters(binsA),oct4I,oct4I-oct4Ici(1,:),oct4Ici(2,:)-oct4I,'b-o','LineWidth',2);   
hold on;
PEo4 = errorbar(edgecenters(binsA)+0.05.*diff(edgecenters(1:2)),oct4E,oct4I-oct4Ici(1,:),oct4Ici(2,:)-oct4I,'m-o','LineWidth',2);
xlim([0.1 0.6]);
ylim([0.5 1.5]);
a=cellstr(num2str(get(gca,'xtick')'*100)); 
pct = char(ones(size(a,1),1)*'%'); 
new_xticks = [char(a),pct];
set(gca,'xticklabel',new_xticks)
ax = gca;
ax.XAxis.MinorTick = 'on';
ax.YAxis.MinorTick = 'on';
xlabel('Gradient Level');
ylabel('Mean Oct4 Level');
legend([PEo4,PIo4],'Edge of Colony','Interior of Colony', 'Location', 'northeast');
set(gca,'FontSize',26);
export_fig TLs3_t65_gradOct4hist.pdf;
close;

%% Find Mean Oct4/Sox2 Ratio of Exterior and Interior Cells at each Concentration Bin
ratioA = oct4A./sox2A;
logratioA = log(ratioA);
ratioE = zeros(1,nbins);
ratioI = zeros(1,nbins);
ratioEci = zeros(2,nbins);
ratioIci = zeros(2,nbins);

for i = 1:nbins    
    ratioE(i) = exp(mean(logratioA(binA==binsA(i) & EAcells)));
    ratioI(i) = exp(mean(logratioA(binA==binsA(i) & IAcells)));
    [~,~,ratioEci(:,i),~] = ttest(logratioA(binA==binsA(i) & EAcells));
    [~,~,ratioIci(:,i),~] = ttest(logratioA(binA==binsA(i) & IAcells)); 
end
ratioEci = exp(ratioEci);
ratioIci = exp(ratioIci);

F4 = figure(4);
%set(gcf, 'Position', get(0, 'Screensize'));
F4.Position(3) = F4.Position(4)*1.61803398875*0.8;
set(F4, 'Color', 'w');
PIr = errorbar(edgecenters(binsA),ratioI,ratioI-ratioIci(1,:),ratioIci(2,:)-ratioI,'k-o','LineWidth',2,'MarkerSize',2,'MarkerFaceColor','k');   
hold on;
PEr = errorbar(edgecenters(binsA)+0.05.*diff(edgecenters(1:2)),ratioE,ratioI-ratioIci(1,:),ratioIci(2,:)-ratioI,'-o','LineWidth',2,'MarkerSize',2, 'Color',[0.5 0.5 0.5]);
set(gca,'LineWidth',2);
set(gca,'FontSize',30);
set(gca,'YScale','log');
xlim([0.05 0.68]);
ylim([0.7 3.5]);
a=cellstr(num2str(get(gca,'xtick')'*100)); 
pct = char(ones(size(a,1),1)*'%'); 
new_xticks = [char(a),pct];
set(gca,'xticklabel',new_xticks)
ax = gca;
ax.XAxis.MinorTick = 'on';
ax.YAxis.MinorTick = 'on';
xlabel('Gradient Level');
ylabel('OCT4/SOX2');
%legend([PEr,PIr],'Edge of Colony','Interior of Colony', 'Location', 'northeast');
export_fig TLs3_t65_gradO4S2ratiohist.pdf;
close;

ratioC = oct4C./sox2C;
save('Fig1b_10hBins.mat','concC','binC','ECcells','ICcells','ratioC');
save('Fig1b_10h.mat', 'edgecenters','binsA','ratioI','ratioE','ratioIci','ratioEci');